"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApiClient = void 0;
const os_1 = __importDefault(require("os"));
const platform_1 = __importDefault(require("platform"));
const axios_1 = __importDefault(require("axios"));
const package_json_1 = require("../package.json");
class ApiClient {
    constructor(authProvider, apiBaseUrl, options) {
        var _a, _b;
        this.authProvider = authProvider;
        this.apiBaseUrl = apiBaseUrl;
        this.options = options;
        this.axiosInstance = axios_1.default.create({
            baseURL: this.apiBaseUrl,
            proxy: (_a = this.options) === null || _a === void 0 ? void 0 : _a.proxy,
            timeout: (_b = this.options) === null || _b === void 0 ? void 0 : _b.timeoutInMs,
            headers: {
                "X-API-Key": this.authProvider.getApiKey(),
                "User-Agent": this.getUserAgent()
            }
        });
    }
    getUserAgent() {
        var _a, _b;
        let userAgent = `fireblocks-sdk-js/${package_json_1.version}`;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.anonymousPlatform)) {
            userAgent += ` (${os_1.default.type()} ${os_1.default.release()}; ${platform_1.default.name} ${platform_1.default.version}; ${os_1.default.arch()})`;
        }
        if ((_b = this.options) === null || _b === void 0 ? void 0 : _b.userAgent) {
            userAgent = `${this.options.userAgent} ${userAgent}`;
        }
        return userAgent;
    }
    issueGetRequest(path, pageMode = false) {
        return __awaiter(this, void 0, void 0, function* () {
            const token = this.authProvider.signJwt(path);
            const res = yield this.axiosInstance.get(path, {
                headers: { "Authorization": `Bearer ${token}` }
            });
            if (pageMode) {
                return {
                    transactions: res.data,
                    pageDetails: {
                        prevPage: res.headers["prev-page"] ? res.headers["prev-page"].toString() : "",
                        nextPage: res.headers["next-page"] ? res.headers["next-page"].toString() : "",
                    }
                };
            }
            return res.data;
        });
    }
    issuePostRequest(path, body, requestOptions) {
        return __awaiter(this, void 0, void 0, function* () {
            const token = this.authProvider.signJwt(path, body);
            const headers = { "Authorization": `Bearer ${token}` };
            const idempotencyKey = requestOptions === null || requestOptions === void 0 ? void 0 : requestOptions.idempotencyKey;
            if (idempotencyKey) {
                headers["Idempotency-Key"] = idempotencyKey;
            }
            return (yield this.axiosInstance.post(path, body, { headers })).data;
        });
    }
    issuePutRequest(path, body) {
        return __awaiter(this, void 0, void 0, function* () {
            const token = this.authProvider.signJwt(path, body);
            return (yield this.axiosInstance.put(path, body, {
                headers: { "Authorization": `Bearer ${token}` }
            })).data;
        });
    }
    issuePatchRequest(path, body) {
        return __awaiter(this, void 0, void 0, function* () {
            const token = this.authProvider.signJwt(path, body);
            return (yield this.axiosInstance.patch(path, body, {
                headers: { "Authorization": `Bearer ${token}` }
            })).data;
        });
    }
    issueDeleteRequest(path) {
        return __awaiter(this, void 0, void 0, function* () {
            const token = this.authProvider.signJwt(path);
            return (yield this.axiosInstance.delete(path, {
                headers: { "Authorization": `Bearer ${token}` }
            })).data;
        });
    }
}
exports.ApiClient = ApiClient;
//# sourceMappingURL=api-client.js.map